@@ -103,6 +103,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_codeguruprofiler
@@ -160,6 +162,9 @@ class _ITriggerProxy(
 
         :param scopes: A list of construct scopes which this trigger will depend on.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ITrigger.execute_after)
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
         return typing.cast(None, jsii.invoke(self, "executeAfter", [*scopes]))
 
     @jsii.member(jsii_name="executeBefore")
@@ -171,6 +176,9 @@ class _ITriggerProxy(
 
         :param scopes: A list of construct scopes which will take a dependency on this trigger.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ITrigger.execute_before)
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
         return typing.cast(None, jsii.invoke(self, "executeBefore", [*scopes]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -226,6 +234,10 @@ class Trigger(
         :param execute_before: Adds this trigger as a dependency on other constructs. This means that this trigger will get executed *before* the given construct(s). You can also use ``trigger.executeBefore()`` to add additional dependants. Default: []
         :param execute_on_handler_change: Re-executes the trigger every time the handler changes. This implies that the trigger is associated with the ``currentVersion`` of the handler, which gets recreated every time the handler or its configuration is updated. Default: true
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Trigger.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = TriggerProps(
             handler=handler,
             execute_after=execute_after,
@@ -244,6 +256,9 @@ class Trigger(
 
         :param scopes: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Trigger.execute_after)
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
         return typing.cast(None, jsii.invoke(self, "executeAfter", [*scopes]))
 
     @jsii.member(jsii_name="executeBefore")
@@ -255,6 +270,9 @@ class Trigger(
 
         :param scopes: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Trigger.execute_before)
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
         return typing.cast(None, jsii.invoke(self, "executeBefore", [*scopes]))
 
 
@@ -299,7 +317,7 @@ class TriggerFunction(
         architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
         architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
         code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
-        current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
+        current_version_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.VersionOptions, typing.Dict[str, typing.Any]]] = None,
         dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
         dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
@@ -314,7 +332,7 @@ class TriggerFunction(
         insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
         layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
-        log_retention_retry_options: typing.Optional[aws_cdk.aws_lambda.LogRetentionRetryOptions] = None,
+        log_retention_retry_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.LogRetentionRetryOptions, typing.Dict[str, typing.Any]]] = None,
         log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
         memory_size: typing.Optional[jsii.Number] = None,
         profiling: typing.Optional[builtins.bool] = None,
@@ -326,7 +344,7 @@ class TriggerFunction(
         timeout: typing.Optional[aws_cdk.core.Duration] = None,
         tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
         max_event_age: typing.Optional[aws_cdk.core.Duration] = None,
         on_failure: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
         on_success: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
@@ -379,6 +397,10 @@ class TriggerFunction(
         :param on_success: The destination for successful invocations. Default: - no destination
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Minimum: 0 Maximum: 2 Default: 2
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(TriggerFunction.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = TriggerFunctionProps(
             code=code,
             handler=handler,
@@ -436,6 +458,9 @@ class TriggerFunction(
 
         :param scopes: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(TriggerFunction.execute_after)
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
         return typing.cast(None, jsii.invoke(self, "executeAfter", [*scopes]))
 
     @jsii.member(jsii_name="executeBefore")
@@ -447,6 +472,9 @@ class TriggerFunction(
 
         :param scopes: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(TriggerFunction.execute_before)
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
         return typing.cast(None, jsii.invoke(self, "executeBefore", [*scopes]))
 
     @builtins.property # type: ignore[misc]
@@ -508,6 +536,11 @@ class TriggerOptions:
                 execute_on_handler_change=False
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(TriggerOptions.__init__)
+            check_type(argname="argument execute_after", value=execute_after, expected_type=type_hints["execute_after"])
+            check_type(argname="argument execute_before", value=execute_before, expected_type=type_hints["execute_before"])
+            check_type(argname="argument execute_on_handler_change", value=execute_on_handler_change, expected_type=type_hints["execute_on_handler_change"])
         self._values: typing.Dict[str, typing.Any] = {}
         if execute_after is not None:
             self._values["execute_after"] = execute_after
@@ -614,6 +647,12 @@ class TriggerProps(TriggerOptions):
                 execute_on_handler_change=False
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(TriggerProps.__init__)
+            check_type(argname="argument execute_after", value=execute_after, expected_type=type_hints["execute_after"])
+            check_type(argname="argument execute_before", value=execute_before, expected_type=type_hints["execute_before"])
+            check_type(argname="argument execute_on_handler_change", value=execute_on_handler_change, expected_type=type_hints["execute_on_handler_change"])
+            check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
         self._values: typing.Dict[str, typing.Any] = {
             "handler": handler,
         }
@@ -743,7 +782,7 @@ class TriggerFunctionProps(aws_cdk.aws_lambda.FunctionProps, TriggerOptions):
         architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
         architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
         code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
-        current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
+        current_version_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.VersionOptions, typing.Dict[str, typing.Any]]] = None,
         dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
         dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
@@ -758,7 +797,7 @@ class TriggerFunctionProps(aws_cdk.aws_lambda.FunctionProps, TriggerOptions):
         insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
         layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
-        log_retention_retry_options: typing.Optional[aws_cdk.aws_lambda.LogRetentionRetryOptions] = None,
+        log_retention_retry_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.LogRetentionRetryOptions, typing.Dict[str, typing.Any]]] = None,
         log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
         memory_size: typing.Optional[jsii.Number] = None,
         profiling: typing.Optional[builtins.bool] = None,
@@ -770,7 +809,7 @@ class TriggerFunctionProps(aws_cdk.aws_lambda.FunctionProps, TriggerOptions):
         timeout: typing.Optional[aws_cdk.core.Duration] = None,
         tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
         code: aws_cdk.aws_lambda.Code,
         handler: builtins.str,
         runtime: aws_cdk.aws_lambda.Runtime,
@@ -846,6 +885,51 @@ class TriggerFunctionProps(aws_cdk.aws_lambda.FunctionProps, TriggerOptions):
             log_retention_retry_options = aws_cdk.aws_lambda.LogRetentionRetryOptions(**log_retention_retry_options)
         if isinstance(vpc_subnets, dict):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
+        if __debug__:
+            type_hints = typing.get_type_hints(TriggerFunctionProps.__init__)
+            check_type(argname="argument max_event_age", value=max_event_age, expected_type=type_hints["max_event_age"])
+            check_type(argname="argument on_failure", value=on_failure, expected_type=type_hints["on_failure"])
+            check_type(argname="argument on_success", value=on_success, expected_type=type_hints["on_success"])
+            check_type(argname="argument retry_attempts", value=retry_attempts, expected_type=type_hints["retry_attempts"])
+            check_type(argname="argument allow_all_outbound", value=allow_all_outbound, expected_type=type_hints["allow_all_outbound"])
+            check_type(argname="argument allow_public_subnet", value=allow_public_subnet, expected_type=type_hints["allow_public_subnet"])
+            check_type(argname="argument architecture", value=architecture, expected_type=type_hints["architecture"])
+            check_type(argname="argument architectures", value=architectures, expected_type=type_hints["architectures"])
+            check_type(argname="argument code_signing_config", value=code_signing_config, expected_type=type_hints["code_signing_config"])
+            check_type(argname="argument current_version_options", value=current_version_options, expected_type=type_hints["current_version_options"])
+            check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
+            check_type(argname="argument dead_letter_queue_enabled", value=dead_letter_queue_enabled, expected_type=type_hints["dead_letter_queue_enabled"])
+            check_type(argname="argument dead_letter_topic", value=dead_letter_topic, expected_type=type_hints["dead_letter_topic"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
+            check_type(argname="argument environment_encryption", value=environment_encryption, expected_type=type_hints["environment_encryption"])
+            check_type(argname="argument ephemeral_storage_size", value=ephemeral_storage_size, expected_type=type_hints["ephemeral_storage_size"])
+            check_type(argname="argument events", value=events, expected_type=type_hints["events"])
+            check_type(argname="argument filesystem", value=filesystem, expected_type=type_hints["filesystem"])
+            check_type(argname="argument function_name", value=function_name, expected_type=type_hints["function_name"])
+            check_type(argname="argument initial_policy", value=initial_policy, expected_type=type_hints["initial_policy"])
+            check_type(argname="argument insights_version", value=insights_version, expected_type=type_hints["insights_version"])
+            check_type(argname="argument layers", value=layers, expected_type=type_hints["layers"])
+            check_type(argname="argument log_retention", value=log_retention, expected_type=type_hints["log_retention"])
+            check_type(argname="argument log_retention_retry_options", value=log_retention_retry_options, expected_type=type_hints["log_retention_retry_options"])
+            check_type(argname="argument log_retention_role", value=log_retention_role, expected_type=type_hints["log_retention_role"])
+            check_type(argname="argument memory_size", value=memory_size, expected_type=type_hints["memory_size"])
+            check_type(argname="argument profiling", value=profiling, expected_type=type_hints["profiling"])
+            check_type(argname="argument profiling_group", value=profiling_group, expected_type=type_hints["profiling_group"])
+            check_type(argname="argument reserved_concurrent_executions", value=reserved_concurrent_executions, expected_type=type_hints["reserved_concurrent_executions"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument security_groups", value=security_groups, expected_type=type_hints["security_groups"])
+            check_type(argname="argument timeout", value=timeout, expected_type=type_hints["timeout"])
+            check_type(argname="argument tracing", value=tracing, expected_type=type_hints["tracing"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
+            check_type(argname="argument code", value=code, expected_type=type_hints["code"])
+            check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
+            check_type(argname="argument runtime", value=runtime, expected_type=type_hints["runtime"])
+            check_type(argname="argument execute_after", value=execute_after, expected_type=type_hints["execute_after"])
+            check_type(argname="argument execute_before", value=execute_before, expected_type=type_hints["execute_before"])
+            check_type(argname="argument execute_on_handler_change", value=execute_on_handler_change, expected_type=type_hints["execute_on_handler_change"])
         self._values: typing.Dict[str, typing.Any] = {
             "code": code,
             "handler": handler,
